@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -119,6 +119,24 @@ class TrackMeSplkFqmParse(StreamingCommand):
         validate=validators.Match("default_threshold_global", r"^\d*\.?\d*$"),
     )
 
+    default_score_fields = Option(
+        doc="""
+        **Syntax:** **default_score_fields=****
+        **Description:** The default score (0-100) for field thresholds when breached, defaults to 100. (integer value)""",
+        require=False,
+        default=100,
+        validate=validators.Match("default_score_fields", r"^\d+$"),
+    )
+
+    default_score_global = Option(
+        doc="""
+        **Syntax:** **default_score_global=****
+        **Description:** The default score (0-100) for global entity thresholds when breached, defaults to 100. (integer value)""",
+        require=False,
+        default=100,
+        validate=validators.Match("default_score_global", r"^\d+$"),
+    )
+
     context = Option(
         doc="""
         **Syntax:** **context=****
@@ -178,6 +196,17 @@ class TrackMeSplkFqmParse(StreamingCommand):
                             threshold_value = float(threshold_value)
                         except (TypeError, ValueError):
                             pass
+                        
+                        # Get score, default to 100 if not present (for backward compatibility)
+                        score = item.get("score")
+                        if score is None:
+                            score = 100
+                        else:
+                            try:
+                                score = int(score)
+                            except (TypeError, ValueError):
+                                score = 100
+                        
                         collection_records_dict[item.get("object_id")] = {
                             "_key": item.get("_key"),
                             "metric_name": item.get("metric_name"),
@@ -186,6 +215,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                             "value": threshold_value,
                             "condition_true": int(item.get("condition_true", 0)),
                             "comment": item.get("comment"),
+                            "score": score,
                         }
                 skip_tracker += 5000
             else:
@@ -905,6 +935,14 @@ class TrackMeSplkFqmParse(StreamingCommand):
         endpoint = f"{self._metadata.searchinfo.splunkd_uri}/services/trackme/v2/splk_fqm/write/fqm_thresholds_add"
 
         if field_thresholds_object_ids and self.context == "live":
+            # Get score, default to 100 if not provided (for backward compatibility)
+            try:
+                score_fields = int(self.default_score_fields)
+                if score_fields < 0 or score_fields > 100:
+                    score_fields = 100
+            except (TypeError, ValueError):
+                score_fields = 100
+            
             data = {
                 "tenant_id": self.tenant_id,
                 "metric_name": "fields_quality.percent_success",
@@ -912,6 +950,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "operator": ">=",
                 "condition_true": 1,
                 "comment": "default threshold",
+                "score": score_fields,
                 "keys_list": ",".join(field_thresholds_object_ids),
             }
             logging.info(
@@ -934,6 +973,14 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 )
 
         if global_thresholds_object_id and self.context == "live":
+            # Get score, default to 100 if not provided (for backward compatibility)
+            try:
+                score_global = int(self.default_score_global)
+                if score_global < 0 or score_global > 100:
+                    score_global = 100
+            except (TypeError, ValueError):
+                score_global = 100
+            
             data = {
                 "tenant_id": self.tenant_id,
                 "metric_name": "fields_quality.percent_success",
@@ -941,6 +988,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "operator": ">=",
                 "condition_true": 1,
                 "comment": "default threshold (meta entity)",
+                "score": score_global,
                 "keys_list": ",".join(global_thresholds_object_id),
             }
             logging.info(
